# coding: utf-8

"""
    XRELY

    API Documentation for XRELY platform  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: contact@xrely.com
    
"""


from __future__ import absolute_import

import unittest

import xrely_lib_client
from xrely_lib_client.models.filter_field import FilterField  # noqa: E501
from xrely_lib_client.rest import ApiException


class TestFilterField(unittest.TestCase):
    """FilterField unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testFilterField(self):
        """Test FilterField"""
        # FIXME: construct object with mandatory attributes with example values
        # model = xrely_lib_client.models.filter_field.FilterField()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    XRELY

    API Documentation for XRELY platform  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: contact@xrely.com
    
"""


from __future__ import absolute_import

# import apis into sdk package
from xrely_lib_client.api.data_api import DataApi
from xrely_lib_client.api.search_api import SearchApi

# import ApiClient
from xrely_lib_client.api_client import ApiClient
from xrely_lib_client.configuration import Configuration
# import models into sdk package
from xrely_lib_client.models.aggrigation_field import AggrigationField
from xrely_lib_client.models.api_response import ApiResponse
from xrely_lib_client.models.data_api_response import DataApiResponse
from xrely_lib_client.models.data_message import DataMessage
from xrely_lib_client.models.data_store_request import DataStoreRequest
from xrely_lib_client.models.doc_store_item import DocStoreItem
from xrely_lib_client.models.filter_field import FilterField
from xrely_lib_client.models.map_object import MapObject
from xrely_lib_client.models.search_request import SearchRequest



# coding: utf-8

"""
    XRELY

    API Documentation for XRELY platform  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: contact@xrely.com
    
"""


import pprint
import re  # noqa: F401

import six


class SearchRequest(object):
    """
    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ak': 'str',
        'q': 'str',
        'size': 'str',
        'agg_field': 'list[AggrigationField]',
        'filter_field': 'list[FilterField]'
    }

    attribute_map = {
        'ak': 'ak',
        'q': 'q',
        'size': 'size',
        'agg_field': 'aggField',
        'filter_field': 'filterField'
    }

    def __init__(self, ak=None, q=None, size=None, agg_field=None, filter_field=None):  # noqa: E501
        """SearchRequest - a model defined """  # noqa: E501

        self._ak = None
        self._q = None
        self._size = None
        self._agg_field = None
        self._filter_field = None
        self.discriminator = None

        if ak is not None:
            self.ak = ak
        if q is not None:
            self.q = q
        if size is not None:
            self.size = size
        if agg_field is not None:
            self.agg_field = agg_field
        if filter_field is not None:
            self.filter_field = filter_field

    @property
    def ak(self):
        """Gets the ak of this SearchRequest.  # noqa: E501

        Account Key  # noqa: E501

        :return: The ak of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._ak

    @ak.setter
    def ak(self, ak):
        """Sets the ak of this SearchRequest.

        Account Key  # noqa: E501

        :param ak: The ak of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._ak = ak

    @property
    def q(self):
        """Gets the q of this SearchRequest.  # noqa: E501

        Query Term  # noqa: E501

        :return: The q of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._q

    @q.setter
    def q(self, q):
        """Sets the q of this SearchRequest.

        Query Term  # noqa: E501

        :param q: The q of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._q = q

    @property
    def size(self):
        """Gets the size of this SearchRequest.  # noqa: E501

        Number of results  # noqa: E501

        :return: The size of this SearchRequest.  # noqa: E501
        :rtype: str
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this SearchRequest.

        Number of results  # noqa: E501

        :param size: The size of this SearchRequest.  # noqa: E501
        :type: str
        """

        self._size = size

    @property
    def agg_field(self):
        """Gets the agg_field of this SearchRequest.  # noqa: E501


        :return: The agg_field of this SearchRequest.  # noqa: E501
        :rtype: list[AggrigationField]
        """
        return self._agg_field

    @agg_field.setter
    def agg_field(self, agg_field):
        """Sets the agg_field of this SearchRequest.


        :param agg_field: The agg_field of this SearchRequest.  # noqa: E501
        :type: list[AggrigationField]
        """

        self._agg_field = agg_field

    @property
    def filter_field(self):
        """Gets the filter_field of this SearchRequest.  # noqa: E501


        :return: The filter_field of this SearchRequest.  # noqa: E501
        :rtype: list[FilterField]
        """
        return self._filter_field

    @filter_field.setter
    def filter_field(self, filter_field):
        """Sets the filter_field of this SearchRequest.


        :param filter_field: The filter_field of this SearchRequest.  # noqa: E501
        :type: list[FilterField]
        """

        self._filter_field = filter_field

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(SearchRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SearchRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    XRELY

    API Documentation for XRELY platform  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: contact@xrely.com
    
"""


#from __future__ import absolute_import
from __future__ import print_function
import unittest
from pprint import pprint
import time
import xrely_lib_client
from xrely_lib_client.rest import ApiException
import json
import ast

class TestSearchApi(unittest.TestCase):
    """SearchApi unit test stubs"""
    api = xrely_lib_client.api.search_api.SearchApi()
    def setUp(self):
        self.api = xrely_lib_client.api.search_api.SearchApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_search_post(self):
        """Test case for search_post

        Provides relevant result for your query  # noqa: E501
        """
        pass

    def test_search_post_count(self):
        body = xrely_lib_client.SearchRequest()
        body.q='a'
        body.ak='c7a505fa518c566e111eb2532efc9685'
        body.size=10
        try:
            api_response = self.api.search_post(body)
            self.assertLessEqual(len(ast.literal_eval(str((api_response.data)['results']))),body.size)
        except ApiException as e:
            pprint("Exception when calling SearchApi->search_post: %s\n" % e)

    def test_search_post_code(self):
        body = xrely_lib_client.SearchRequest()
        body.q='a'
        body.ak='c7a505fa518c566e111eb2532efc9685'
        body.size=10
        try:
            api_response = self.api.search_post(body)
            self.assertEqual(0,int(api_response.code))
        except ApiException as e:
            pprint("Exception when calling SearchApi->search_post: %s\n" % e)


    def test_search_post_data(self):
        body = xrely_lib_client.SearchRequest()
        body.q='a'
        body.ak='c7a505fa518c566e111eb2532efc9685'
        body.size=10
        try:
            api_response = self.api.search_post(body)
            self.assertIsNotNone(api_response.data)
        except ApiException as e:
            pprint("Exception when calling SearchApi->search_post: %s\n" % e)

    def test_search_suggestions_get_count(self):
        q = 'a' # str | Search Term or Keyword
        ak = 'c7a505fa518c566e111eb2532efc9685' # str | Account Key
        size = 10 # int | Number Of Results Required (optional)
        try:
            api_response = self.api.search_suggestions_get(q, ak, size=size)
            self.assertLessEqual(len(ast.literal_eval(str((api_response.data)['results']))),size)
        except ApiException as e:
            pprint("Exception when calling SearchApi->search_suggestions_get: %s\n" % e)
        
    def test_search_suggestions_get_code(self):
        q = 'a' # str | Search Term or Keyword
        ak = 'c7a505fa518c566e111eb2532efc9685' # str | Account Key
        size = 10 # int | Number Of Results Required (optional)
        try:
            api_response = self.api.search_suggestions_get(q, ak, size=size)
            self.assertEqual(0,api_response.code)
        except ApiException as e:
            pprint("Exception when calling SearchApi->search_suggestions_get: %s\n" % e)


    def test_search_suggestions_get_data(self):
        q = 'a' # str | Search Term or Keyword
        ak = 'c7a505fa518c566e111eb2532efc9685' # str | Account Key
        size = 10 # int | Number Of Results Required (optional)
        try:
            api_response = self.api.search_suggestions_get(q, ak, size=size)
            self.assertIsNotNone(api_response.data)
        except ApiException as e:
            pprint("Exception when calling SearchApi->search_suggestions_get: %s\n" % e)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    XRELY

    API Documentation for XRELY platform  # noqa: E501

    OpenAPI spec version: 1.0.0
    Contact: contact@xrely.com
    
"""


#from __future__ import absolute_import

from __future__ import print_function
import time
import xrely_lib_client
from xrely_lib_client.rest import ApiException
from pprint import pprint
import unittest

class TestDataApi(unittest.TestCase):
    """DataApi unit test stubs"""

    def setUp(self):
        self.api = xrely_lib_client.api.data_api.DataApi()  # noqa: E501
        self.body = xrely_lib_client.DataStoreRequest() # DataStoreRequest |  (optional)
        data_object = xrely_lib_client.DocStoreItem()
        data_object.keyword = "convonix kw-python"
        data_object.url = "http://www.convonix.com/convonix-python"
        map = {}
        map['type'] = "datatype"
        map['info'] = "website"
        data_object.data = map
        self.body.secret_key = "68ceece96a303ca6d4c1e9d01b674c02d4602681ebf344ef8e8b43f21cca4c03"
        arr_obj=[]
        arr_obj.append(data_object)
        self.body.docs = arr_obj

    def tearDown(self):
        pass

    def test_data_store_post(self):
        try:
            api_response = self.api.data_store_post(body=self.body)
            self.assertTrue(api_response.data.committed)
            self.assertEqual("1 documents inserted sucessfully!!",api_response.data.message)
        except ApiException as e:
            print("Exception when calling DataApi->data_store_post: %s\n" % e)

    def test_data_store_delete(self):
        try:
            api_response = self.api.data_store_delete(body=self.body)
            self.assertTrue(api_response.data.committed)
            self.assertEqual("1 documents deleted sucessfully!!",api_response.data.message)
        except ApiException as e:
            print("Exception when calling DataApi->data_store_delete: %s\n" % e)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    xrely

    API Documentation for xrely platform. For more information please visit https://www.xrely.com.

    OpenAPI spec version: 1.0.0
    Contact: info@xrely.com
    
"""


from setuptools import setup, find_packages  # noqa: H301

NAME = "xrely_lib_client"
VERSION = "1.0.0"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi>=2017.4.17",
    "python-dateutil>=2.1",
    "six>=1.10",
    "urllib3>=1.23"
]
    

setup(
    name=NAME,
    version=VERSION,
    description="client library for xrely platform.",
    author_email="info@xrely.com",
    url="https://www.xrely.com",
    keywords=["Web search intelligence","Autocrawl search","Intelligent search engine","install site search","Autocomplete search solution","Autocrawl Search","Search discovery"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
    client library for xrely platform. For more information please visit https://www.xrely.com
    """
)
